Module loader

Module loader 

Validation boundary for graph-query response bytes.

SDKs own query construction. This module owns the shared response aliases and turns the resulting bytes into a graph only after every row and topology invariant has been validated.

Structs

GraphLoadSpec
Metadata required to interpret one graph query response.

Enums

GraphLoadError
Failure to validate raw graph response bytes.

Constants

EDGE_ID
Projected stable edge ID alias.
EDGE_KEY
Projected Graphify multigraph key alias.
EDGE_LABEL
Projected edge label alias.
EDGE_SOURCE
Projected internal source-node ID alias.
EDGE_TARGET
Projected internal target-node ID alias.
EDGE_WEIGHT
Projected algorithm weight alias.
EXTERNAL_ID
Projected public external node ID alias.
NODE_ID
Projected internal node ID alias.
NODE_LABEL
Projected node label alias.
PRIVATE_PREFIX
Prefix reserved for graph loader projection aliases.

Functions

graph_from_response
Validate raw /v2/query response bytes and construct an immutable graph.