Validation boundary for graph-query response bytes.
SDKs own query construction. This module owns the shared response aliases and turns the resulting bytes into a graph only after every row and topology invariant has been validated.
Structs
- Graph
Load Spec - Metadata required to interpret one graph query response.
Enums
- Graph
Load Error - Failure to validate raw graph response bytes.
Constants
- EDGE_ID
- Projected stable edge ID alias.
- EDGE_
KEY - Projected Graphify multigraph key alias.
- EDGE_
LABEL - Projected edge label alias.
- EDGE_
SOURCE - Projected internal source-node ID alias.
- EDGE_
TARGET - Projected internal target-node ID alias.
- EDGE_
WEIGHT - Projected algorithm weight alias.
- EXTERNAL_
ID - Projected public external node ID alias.
- NODE_ID
- Projected internal node ID alias.
- NODE_
LABEL - Projected node label alias.
- PRIVATE_
PREFIX - Prefix reserved for graph loader projection aliases.
Functions
- graph_
from_ response - Validate raw
/v2/queryresponse bytes and construct an immutable graph.